==> zio-aws-networkmanager_2.13-5.17.152.1-sources.jar: zio/aws/networkmanager/model/DeleteAttachmentResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteAttachmentResponse(
    attachment: Option[zio.aws.networkmanager.model.Attachment] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.DeleteAttachmentResponse = {
    import DeleteAttachmentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.DeleteAttachmentResponse
      .builder()
      .optionallyWith(attachment.map(value => value.buildAwsValue()))(
        _.attachment
      )
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.DeleteAttachmentResponse.ReadOnly =
    zio.aws.networkmanager.model.DeleteAttachmentResponse.wrap(buildAwsValue())
}
object DeleteAttachmentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.DeleteAttachmentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.DeleteAttachmentResponse =
      zio.aws.networkmanager.model
        .DeleteAttachmentResponse(attachment.map(value => value.asEditable))
    def attachment: Option[zio.aws.networkmanager.model.Attachment.ReadOnly]
    def getAttachment
        : ZIO[Any, AwsError, zio.aws.networkmanager.model.Attachment.ReadOnly] =
      AwsError.unwrapOptionField("attachment", attachment)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.DeleteAttachmentResponse
  ) extends zio.aws.networkmanager.model.DeleteAttachmentResponse.ReadOnly {
    override val attachment
        : Option[zio.aws.networkmanager.model.Attachment.ReadOnly] = scala
      .Option(impl.attachment())
      .map(value => zio.aws.networkmanager.model.Attachment.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.DeleteAttachmentResponse
  ): zio.aws.networkmanager.model.DeleteAttachmentResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-networkmanager_2.13-5.17.295.6-sources.jar: zio/aws/networkmanager/model/DeleteAttachmentResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteAttachmentResponse(
    attachment: Optional[zio.aws.networkmanager.model.Attachment] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.DeleteAttachmentResponse = {
    import DeleteAttachmentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.DeleteAttachmentResponse
      .builder()
      .optionallyWith(attachment.map(value => value.buildAwsValue()))(
        _.attachment
      )
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.DeleteAttachmentResponse.ReadOnly =
    zio.aws.networkmanager.model.DeleteAttachmentResponse.wrap(buildAwsValue())
}
object DeleteAttachmentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.DeleteAttachmentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.DeleteAttachmentResponse =
      zio.aws.networkmanager.model
        .DeleteAttachmentResponse(attachment.map(value => value.asEditable))
    def attachment: Optional[zio.aws.networkmanager.model.Attachment.ReadOnly]
    def getAttachment
        : ZIO[Any, AwsError, zio.aws.networkmanager.model.Attachment.ReadOnly] =
      AwsError.unwrapOptionField("attachment", attachment)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.DeleteAttachmentResponse
  ) extends zio.aws.networkmanager.model.DeleteAttachmentResponse.ReadOnly {
    override val attachment
        : Optional[zio.aws.networkmanager.model.Attachment.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.attachment())
        .map(value => zio.aws.networkmanager.model.Attachment.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.DeleteAttachmentResponse
  ): zio.aws.networkmanager.model.DeleteAttachmentResponse.ReadOnly =
    new Wrapper(impl)
}
